# accsr 

This lightweight library contains utilities for managing, loading, uploading, opening and generally wrangling data and
configurations. It was battle tested in multiple projects at appliedAI. 

Please open new issues for bugs, feature requests and extensions. See more details about the structure and
workflow in the [developer's readme](README_dev.md). 

## Overview

Source code documentation and usage examples are [here](TODO). We also provide notebooks with examples in *TODO*.

## Installation

Install the latest release with
```shell script
pip install accsr
```

To live on the edge, install the latest develop version with
```shell script
pip install --pre accsr
```

